
{% extends 'full.tpl'%}

{% block header %}
{{ super() }}

<link rel="stylesheet" type="text/css" href="https://cdn.jupyter.org/notebook/5.4.0/style/style.min.css">

<style>

{-% if data.is_ribbon %-}
{-% include 'ribbon.css' %-}
{-% endif %-}

{-% if data.hide_code %-}
{-% include 'hide_prompt.css' %-}
{-% endif %-}
</style>

{-% if data.ipywidgets %-}
<script src="https://unpkg.com/@jupyter-widgets/html-manager@*/dist/embed-amd.js" crossorigin="anonymous"></script>
{-% endif %-}

{% endblock header %}


{% block body %}
{{ super() }}

{-% if data.is_ribbon %-}
    <div class="corner-ribbon __$data.ribbon_position$__ sticky __$data.ribbon_color$__">__$data.ribbon_text$__</div>
{-% endif %-}
{% endblock body %}


{% block input_group %}

{-% if data.hide_code %-}
{-% else %-}
{{ super() }}
{-% endif %-}

{% endblock input_group %}


{% block any_cell %}

{% if cell.get('source', '').startswith('# NBCONVERT IMPORTANT') or cell['metadata'].get('nbconvert', '') == 'important' %}
    <div style="border:__$data.important_border$__ solid __$data.important_color$__; background-color: __$data.important_background_color$__">
        {{ super() }}
    </div>
{% elif cell.get('source', '').startswith('# NBCONVERT REMOVE') or cell['metadata'].get('nbconvert', '') == 'remove' %}
    <div>
    </div>
{% else %}
    {{ super() }}
{% endif %}

{% endblock any_cell %}
